"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var path = require("path");
// BUILD STEP IMPLEMENTATIONS
var assets_1 = require("./steps/assets");
var ngc_1 = require("./steps/ngc");
var package_1 = require("./steps/package");
var rollup_1 = require("./steps/rollup");
var sorcery_1 = require("./steps/sorcery");
var tsc_1 = require("./steps/tsc");
var copy_1 = require("./util/copy");
var json_1 = require("./util/json");
var rimraf_1 = require("./util/rimraf");
// Logging
var log_1 = require("./util/log");
exports.ngPackage = function (opts) {
    log_1.info("Building Angular library from " + opts.project);
    if (!path.isAbsolute(opts.project)) {
        opts.project = path.resolve(process.cwd(), opts.project);
    }
    /** Project configuration */
    var ngPkg;
    // 0. READ `ng-package.json` and obtain model
    return package_1.readPackage(opts.project)
        .then(function (p) {
        ngPkg = p;
        // 1. CLEAN
        return Promise.all([
            rimraf_1.rimraf(p.dest),
            rimraf_1.rimraf(p.workingDirectory)
        ]);
    })
        .then(function () { return assets_1.processAssets(ngPkg.src, ngPkg.workingDirectory + "/ts"); })
        .then(function () { return ngc_1.prepareTsConfig(ngPkg, ngPkg.workingDirectory + "/ts/tsconfig.lib.json")
        .then(function (tsConfigFile) { return ngc_1.ngc(tsConfigFile, ngPkg.workingDirectory + "/ts"); })
        .then(function (es2015EntryFile) {
        // XX: see #46 - ngc only references to closure-annotated ES6 sources
        return sorcery_1.remapSourcemap(ngPkg.workingDirectory + "/ts/" + ngPkg.flatModuleFileName + ".js")
            .then(function () { return Promise.resolve(es2015EntryFile); });
    }); })
        .then(function (es2015EntryFile) {
        return rollup_1.rollup({
            moduleName: ngPkg.meta.name,
            entry: es2015EntryFile,
            format: 'es',
            dest: ngPkg.workingDirectory + "/" + ngPkg.artefacts.es2015,
            externals: ngPkg.libExternals
        })
            .then(function () { return sorcery_1.remapSourcemap(ngPkg.workingDirectory + "/" + ngPkg.artefacts.es2015); });
    })
        .then(function () {
        return tsc_1.downlevelWithTsc(ngPkg.workingDirectory + "/" + ngPkg.artefacts.es2015, ngPkg.workingDirectory + "/" + ngPkg.artefacts.module)
            .then(function () { return sorcery_1.remapSourcemap(ngPkg.workingDirectory + "/" + ngPkg.artefacts.module); });
    })
        .then(function () {
        return rollup_1.rollup({
            moduleName: ngPkg.meta.name,
            entry: ngPkg.workingDirectory + "/" + ngPkg.artefacts.module,
            format: 'umd',
            dest: ngPkg.workingDirectory + "/" + ngPkg.artefacts.main,
            externals: ngPkg.libExternals
        })
            .then(function () { return sorcery_1.remapSourcemap(ngPkg.workingDirectory + "/" + ngPkg.artefacts.main); });
    })
        .then(function () { return copy_1.copyFiles(ngPkg.workingDirectory + "/" + ngPkg.meta.scope + "/**/*.{js,js.map}", ngPkg.dest + "/" + ngPkg.meta.scope); })
        .then(function () { return copy_1.copyFiles(ngPkg.workingDirectory + "/bundles/**/*.{js,js.map}", ngPkg.dest + "/bundles"); })
        .then(function () { return copy_1.copyFiles(ngPkg.workingDirectory + "/ts/**/*.{d.ts,metadata.json}", "" + ngPkg.dest); })
        .then(function () { return copy_1.copyFiles(ngPkg.src + "/README.md", ngPkg.dest); })
        .then(function () { return copy_1.copyFiles(ngPkg.src + "/LICENSE", ngPkg.dest); })
        .then(function () { return json_1.modifyJsonFiles(ngPkg.dest + "/**/*.js.map", function (sourceMap) {
        sourceMap['sources'] = sourceMap['sources']
            .map(function (path) { return path.replace('../ts', ngPkg.meta.scope ? "~/" + ngPkg.meta.scope + "/" + ngPkg.meta.name : "~/" + ngPkg.meta.name); });
        return sourceMap;
    }); })
        .then(function () { return package_1.createPackage(ngPkg.src, ngPkg.dest, ngPkg.artefacts); })
        .then(function () {
        log_1.success("Built Angular library from " + ngPkg.src + ", written to " + ngPkg.dest);
    })
        .catch(function (err) {
        // Report error messages and throw the error further up
        log_1.error(err);
        return Promise.reject(err);
    });
};
//# sourceMappingURL=ng-packagr.js.map