"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var path = require("path");
var json_schema_1 = require("@ngtools/json-schema");
var ng_package_1 = require("../model/ng-package");
var json_1 = require("../util/json");
var schemaPromise = json_1.readJson(path.resolve(__dirname, '..', '..', 'ng-package.schema.json'))
    .then(function (jsonSchema) { return json_schema_1.SchemaClassFactory(jsonSchema); });
/**
 * Reads an Angular package definition file from 'ng-package.json'
 *
 * @param file path pointing to `ng-package.json` file
 */
exports.readPackage = function (file) {
    var base = path.dirname(file);
    // read 'ng-package.json'
    return json_1.readJson(file).then(function (ngPkg) {
        // resolve pathes relative to `ng-package.json` file
        var dir = path.resolve(base, ngPkg.src || '.');
        // read 'package.json'
        return json_1.readJson(path.resolve(dir, 'package.json')).then(function (pkg) {
            // read 'ng-package.schema.json'
            return schemaPromise.then(function (SchemaClass) {
                var schema = new SchemaClass(ngPkg);
                return Promise.resolve(new ng_package_1.NgPackage(pkg, ngPkg, base, schema));
            });
        });
    });
};
/**
 * Creates a `package.json` file by reading one from the `src` folder, adding additional
 * properties, and writing to to `dest` folder
 *
 * @param src Source folder
 * @param dest Destination folder
 * @param additionalProperties These properties are added to the `package.json`
 */
exports.createPackage = function (src, dest, additionalProperties) {
    return json_1.readJson(path.resolve(src, 'package.json')).then(function (packageJson) {
        // set additional properties
        if (additionalProperties) {
            Object.keys(additionalProperties).forEach(function (key) {
                packageJson[key] = additionalProperties[key];
            });
        }
        return json_1.writeJson(packageJson, dest + "/package.json");
    });
};
//# sourceMappingURL=package.js.map