"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var glob = require('glob');
var fs_1 = require("../util/fs");
/**
 * Reads a JSON file.
 *
 * @param file Source file name.
 */
exports.readJson = function (file) {
    return fs_1.readFile(file)
        .then(function (content) { return Promise.resolve(JSON.parse(content)); });
};
/**
 * Writes a JSON file.
 *
 * @param object Object literal that is stringified.
 * @param file Target file name.
 */
exports.writeJson = function (object, file) {
    return fs_1.writeFile(file, JSON.stringify(object, undefined, 2));
};
/**
 * Modifies a set of JSON files by invoking `modifyFn`
 *
 * @param globPattern A glob pattern matching several files. Example: '**\/*.js.map'
 * @param modifyFn A callback function that tajes a JSON-parsed input and should return an output
 *                  that will be JSON-stringified
 */
exports.modifyJsonFiles = function (globPattern, modifyFn) {
    return new Promise(function (resolve, reject) {
        glob(globPattern, function (err, files) {
            if (err) {
                reject(err);
            }
            resolve(files);
        });
    })
        .then(function (fileNames) { return Promise.all(fileNames.map(function (fileName) { return fs_1.readFile(fileName)
        .then(function (fileContent) { return fs_1.writeFile(fileName, JSON.stringify(modifyFn(JSON.parse(fileContent)))); }); })); })
        .then(function () { return Promise.resolve(); });
};
//# sourceMappingURL=json.js.map